@@ -6,6 +6,7 @@ from bwikibot.api import Wiki, datetime2zulu
 from bwikibot.ui import shift_block
 
 SESSION_FILE = 'cli.session'
+SECONDARY_SESSION_FILE = 'cli_secondary.session'
 
 def main():
     run(*sys.argv)
@@ -16,8 +17,12 @@ def run(*argv):
         print('You should pass action:')
         show_doc(actions)
     else:
-        actions[argv[1]](*argv[2:])
-
+        action = actions.get(argv[1])
+        if action:
+            action(*argv[2:])
+        else:
+            print('Action "%s" not found.' % argv[1])
+            print('Available actions: %s' % ', '.join(actions.keys()))
     
 actions = {}
 
@@ -29,10 +34,11 @@ def action(name):
     return decorate
 
 def load_extensions():
-    ''' trigger action decorator in extensions '''
+    ''' Trigger action decorator in extensions '''
     from bwikibot import extensions
 
 def show_doc(actions):
+    ''' Prints documentation about actions '''
     maxname = max(len(k) for k in actions.keys())
     for action, function in actions.items():
         doc = function.__doc__ or ''.join((
@@ -45,59 +51,85 @@ def show_doc(actions):
             width=maxname,
         ))
 
-def get_wiki():
+def get_wiki(session_file=SESSION_FILE):
     wiki = Wiki()
-    wiki.session_file(SESSION_FILE)
+    wiki.session_file(session_file)
     return wiki
 
-@action('throttle')
-def throttle(delay=None):
-    ''' Set or get delay between queries '''
-    wiki = get_wiki()
+def get_secondary_wiki():
+    return get_wiki(session_file=SECONDARY_SESSION_FILE)
+
+
+def throttle(session_file, delay):
+    wiki = get_wiki(session_file)
     if not delay:
         print(wiki.throttle)
     else:
         wiki.throttle = float(delay)
-        wiki.save(SESSION_FILE)
+        wiki.save(session_file)
+
+@action('throttle')
+def throttle1(delay=None):
+    ''' Set or get delay between queries.  '''
+    throttle(SESSION_FILE, delay)
+
+@action('throttle2')
+def throttle2(delay=None):
+    ''' Set or get delay between queries for secondary wiki. '''
+    throttle(SECONDARY_SESSION_FILE, delay)
 
 
-@action('read')
-def read_page(*args):
-    ''' Print page which's name passed in param to stdout '''
+def read_page(session_file, *args):
     name = ' '.join(args).strip()
     if not name:
         print('Pass page name as last param')
         return
-    wiki = get_wiki()
+    wiki = get_wiki(session_file)
     print(wiki.page(name).read())
 
+@action('read')
+def read_page1(*args):
+    ''' Print page which's name passed in param to stdout '''
+    read_page(SESSION_FILE, *args)
 
-@action('autocomplete')
-def autocomplete(*args):
-    ''' Print list of page names which starts from passed prefix '''
+@action('read2')
+def read_page2(*args):
+    ''' Print page from secondary wiki which's name passed in param to stdout '''
+    read_page(SECONDARY_SESSION_FILE, *args)
+
+def autocomplete(session_file, *args):
     prefix = ' '.join(args)
-    wiki = get_wiki()
+    wiki = get_wiki(session_file)
     print('\n'.join(
         wiki.opensearch(prefix)
     ))
 
-@action('login')
-def login():
-    ''' Login to site with domain passed in param '''
+@action('autocomplete')
+def autocomplete1(*args):
+    ''' Print list of page names which starts from passed prefix '''
+    autocomplete(SESSION_FILE, *args)
+
+@action('autocomplete2')
+def autocomplete1(*args):
+    ''' Print list of page names which starts from passed prefix for secondary wiki'''
+    autocomplete(SECONDARY_SESSION_FILE, *args)
+
+def login(session_file):
     try:
-        logout()
+        os.remove(session_file)
     except OSError:
         pass
-    get_wiki()
+    get_wiki(session_file)
 
+@action('login')
+def login1():
+    ''' Login to primary wiki '''
+    login(SESSION_FILE)
 
-@action('endpoint')
-def change_endpoint(*args):
-    ''' Change endpoing but don't change cookies (for wiki families) '''
-    url = ' '.join(args)
-    wiki = get_wiki()
-    wiki.set_endpoint(url)
-    wiki.save(SESSION_FILE)
+@action('login2')
+def login2():
+    ''' Login to secondary wiki '''
+    login(SECONDARY_SESSION_FILE)
 
 
 @action('logout')
@@ -105,9 +137,12 @@ def logout():
     ''' Delete session file '''
     os.remove(SESSION_FILE)
 
-@action('write')
-def write_page(*args):
-    ''' Read text from stdio and save to page with name passed in param '''
+@action('logout2')
+def logout2():
+    ''' Delete session file '''
+    os.remove(SECONDARY_SESSION_FILE)
+
+def write_page(session_file, *args):
     name = ' '.join(args)
     wiki = get_wiki()
 
@@ -117,6 +152,16 @@ def write_page(*args):
 
     wiki.page(name).write(''.join(text), 'cli editing')
 
+@action('write')
+def write_page1(*args):
+    ''' Read text from stdio and save to page with name passed in param '''
+    write_page(SESSION_FILE, *args)
+
+@action('write2')
+def write_page2(*args):
+    ''' Read text from stdio and save to page on secondary wiki with name passed in param '''
+    write_page(SECONDARY_SESSION_FILE, *args)
+
 @action('now')
 def get_now():
     ''' Prints current ISO-formatted zulu time '''
